<?php

/**
 * add a confirmation popup before publishing any posts
 */

if( isset($options_customize['aiows_add_publish_confirm_popup_checkbox']) && ($options_customize['aiows_add_publish_confirm_popup_checkbox'] == 1) ) {
    
    
    // Fire settings file!
    require_once dirname( __FILE__ ) . '/inc/class-publish-confirm.php';
    add_action( 'admin_init', array( AIOWS_Publish_Confirm::get_instance(), 'setup' ) );

}


/**
 * disable admin bar for all users
 */

if( isset($options_customize['aiows_disable_admin_bar_all_checkbox']) && ($options_customize['aiows_disable_admin_bar_all_checkbox'] == 'For All Users') ) {
add_filter( 'show_admin_bar', '__return_false' );
}
elseif( isset($options_customize['aiows_disable_admin_bar_all_checkbox']) && ($options_customize['aiows_disable_admin_bar_all_checkbox'] == 'For All Users Except Administrator') ) {
function aiows_remove_function_admin_bar($content) {
    return ( current_user_can( 'administrator' ) ) ? $content : false;
}
add_filter( 'show_admin_bar' , 'aiows_remove_function_admin_bar');
} else {}


/**
 * remove admin bar logo
 */

if( isset($options_customize['aiows_disable_admin_logo_checkbox']) && ($options_customize['aiows_disable_admin_logo_checkbox'] == 1) ) {
    function aiows_remove_wp_logo() {
    global $wp_admin_bar;
    $wp_admin_bar->remove_menu('wp-logo');
    }
    add_action( 'wp_before_admin_bar_render', 'aiows_remove_wp_logo' );

}

/*
 * disallow file edit
 */


if( isset($options_customize['aiows_disable_file_editor_checkbox']) && ($options_customize['aiows_disable_file_editor_checkbox'] == 1) ) {
   if( !defined('DISALLOW_FILE_EDIT') ){
    define( 'DISALLOW_FILE_EDIT', true );
}
}

/*
 * disable help tabs
 */

if( isset($options_customize['aiows_disable_help_tab_checkbox']) && ($options_customize['aiows_disable_help_tab_checkbox'] == 1) ) {
   add_filter( 'contextual_help', 'aiows_remove_help_tabs'); // Removing help tab filter
        function aiows_remove_help_tabs(){
           $screen = get_current_screen();
            $screen->remove_help_tabs();
        }
}

/*
 * disable screen options
 */

if( isset($options_customize['aiows_disable_screen_tab_checkbox']) && ($options_customize['aiows_disable_screen_tab_checkbox'] == 1) ) {
   add_filter('screen_options_show_screen', '__return_false');
}

/*
 * enable wp link manager
 */

if( isset($options_customize['aiows_enable_wp_link_manager_checkbox']) && ($options_customize['aiows_enable_wp_link_manager_checkbox'] == 1) ) {
   add_filter( 'pre_option_link_manager_enabled', '__return_true' );
}

/*
 * enable category count
 */

if( isset($options_customize['aiows_enable_category_count_checkbox']) && ($options_customize['aiows_enable_category_count_checkbox'] == 1) ) {
   
// https://stackoverflow.com/questions/13117968/how-to-display-post-count-in-categories-metabox-in-dashboard/15845723#15845723

   // The hook "load-{$pagenow}" only runs in admin and in the specified page
add_action( 'load-post-new.php', 'aiows_add_filter_category' );
add_action( 'load-post.php', 'aiows_add_filter_category' );

function aiows_add_filter_category()
{
    // Run only in correct post type
    global $typenow;
    if( 'post' != $typenow )
        return;

    add_filter( 'the_category', 'aiows_filter_category_so' );
}

function aiows_filter_category_so( $cat_name ) {
    $cat_id = get_cat_ID( $cat_name );
    $category = get_category( $cat_id );
    $count = $category->category_count;
    return "$cat_name ($count)";
}
}

/*
 * single column dashboard
 */

if( isset($options_customize['aiows_enable_single_column_dashboard_checkbox']) && ($options_customize['aiows_enable_single_column_dashboard_checkbox'] == 1) ) {
   
// http://www.wprecipes.com/how-to-bring-back-single-column-dashboard-in-wordpress-3-8/

// force one-column dashboard
function aiows_screen_layout_columns($columns) {
    $columns['dashboard'] = 1;
    return $columns;
}
add_filter('screen_layout_columns', 'aiows_screen_layout_columns');

function aiows_screen_layout_dashboard() { return 1; }
add_filter('get_user_option_screen_layout_dashboard', 'aiows_screen_layout_dashboard');

}

/*
 * page ecerpts
 */

if( isset($options_customize['aiows_enable_excerpt_on_pages_checkbox']) && ($options_customize['aiows_enable_excerpt_on_pages_checkbox'] == 1) ) {
   // http://www.wpbeginner.com/plugins/add-excerpts-to-your-pages-in-wordpress/
add_action( 'init', 'aiows_add_excerpts_to_pages' );
      
function aiows_add_excerpts_to_pages() {
     add_post_type_support( 'page', 'excerpt' );
}
}

  /**
     * Disable wordpress emoji
     */

if( isset($options_customize['aiows_disable_emoji_checkbox']) && ($options_customize['aiows_disable_emoji_checkbox'] == 1) ) {
    
add_action( 'init', 'aiows_disable_emojis' );

  function aiows_disable_emojis() {

    remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
    remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
    remove_action( 'wp_print_styles', 'print_emoji_styles' );
    remove_action( 'admin_print_styles', 'print_emoji_styles' );    
    remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
    remove_filter( 'comment_text_rss', 'wp_staticize_emoji' );  
    remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
    add_filter( 'tiny_mce_plugins', 'aiows_disable_emojis_tinymce' );
    add_filter( 'wp_resource_hints', 'aiows_disable_emojis_remove_dns_prefetch', 10, 2 );
  }

  function aiows_disable_emojis_tinymce( $plugins ) {
    if ( is_array( $plugins ) ) {
        return array_diff( $plugins, array( 'wpemoji' ) );
    } else {
        return array();
    }
  }

  function aiows_disable_emojis_remove_dns_prefetch( $urls, $relation_type ) {
    if ( 'dns-prefetch' == $relation_type ) {
        /** This filter is documented in wp-includes/formatting.php */
        $emoji_svg_url = apply_filters( 'emoji_svg_url', 'https://s.w.org/images/core/emoji/2.2.1/svg/' );

        $urls = array_diff( $urls, array( $emoji_svg_url ) );
  }

    return $urls;
}

}

    /**
     * disable autosave post
     */

if( isset($options_customize['aiows_disable_post_autosave_checkbox']) && ($options_customize['aiows_disable_post_autosave_checkbox'] == 0) ) {
    add_action( 'wp_print_scripts', 'aiows_plugin_kill_autosave' );
    function aiows_plugin_kill_autosave() {
        wp_deregister_script('autosave');
    }

}

    /**
     * disable auto posr revision
     */

if( isset($options_customize['aiows_disable_post_revision_checkbox']) && ($options_customize['aiows_disable_post_revision_checkbox'] == 1) ) {
    remove_action ( 'pre_post_update', 'wp_save_post_revision' );

}

    /**
     * disable autodns prefetch
     */

if( isset($options_customize['aiows_disable_dns_prefetch_checkbox']) && ($options_customize['aiows_disable_dns_prefetch_checkbox'] == 1) ) {
    function aiows_remove_dns_prefetch( $hints, $relation_type ) {
    if ( 'dns-prefetch' === $relation_type ) {
        return array_diff( wp_dependencies_unique_hosts(), $hints );
    }

    return $hints;
    }

add_filter( 'wp_resource_hints', 'aiows_remove_dns_prefetch', 10, 2 );

}


/*
 * svg support
 */

if( isset($options_customize['aiows_add_support_svg_checkbox']) && ($options_customize['aiows_add_support_svg_checkbox'] == 1) ) {
   function aiows_custom_myme_types($mime_types){
    $mime_types['svg'] = 'image/svg+xml'; //Adding svg extension
    return $mime_types;
}
add_filter('upload_mimes', 'aiows_custom_myme_types', 1, 1);
}
