<?php

/*
 * Require plugin.php
 */ 
if ( ! function_exists( 'is_plugin_active_for_network' ) ) {
    require_once( ABSPATH . '/wp-admin/includes/plugin.php' );
}

/**
 * Activation and deactivation with Cache Support
*/

function aiows_maintenance_mode_on_activation()  {
  
    // Clear Cachify Cache
    if ( has_action('cachify_flush_cache') ) {
    do_action('cachify_flush_cache');
    }
    
    // Clear Super Cache
    if ( function_exists( 'wp_cache_clear_cache' ) ) {
    ob_end_clean();
    wp_cache_clear_cache();
    }
    
    // Clear W3 Total Cache
    if ( function_exists( 'w3tc_pgcache_flush' ) ) {
    ob_end_clean();
    w3tc_pgcache_flush();
    }
    
    // Clear WP-Rocket Cache
    if ( function_exists( 'rocket_clean_domain' ) ) {
    rocket_clean_domain();
    }
}

function aiows_maintenance_mode_on_deactivation() {
  
    // Clear Cachify Cache
    if ( has_action('cachify_flush_cache') ) {
    do_action('cachify_flush_cache');
    }
    
    // Clear Super Cache
    if ( function_exists( 'wp_cache_clear_cache' ) ) {
    ob_end_clean();
    wp_cache_clear_cache();
    }
    
    // Clear W3 Total Cache
    if ( function_exists( 'w3tc_pgcache_flush' ) ) {
    ob_end_clean();
    w3tc_pgcache_flush();
    }
    
    // Clear WP-Rocket Cache
    if ( function_exists( 'rocket_clean_domain' ) ) {
    rocket_clean_domain();
    }
}

register_activation_hook( __FILE__, 'aiows_maintenance_mode_on_activation' );
register_deactivation_hook( __FILE__, 'aiows_maintenance_mode_on_deactivation' );


/**
 * Alert message when active
*/
function aiows_admin_notices() {
	echo '<div id="message" class="notice notice-warning fade"><p>' . __( '<strong>Maintenance mode</strong> is currently <strong>active</strong>!', 'all-in-one-wp-solution' ) . ' <a href="admin.php?page=all-in-one-wp-solution&tab=maintenance">' . __( 'Deactivate it, when work is done', 'all-in-one-wp-solution' ) . '</a>.</p></div>';
}

function aiows_network_admin_notices() {
    echo '<div id="message" class="notice notice-warning fade"><p>' . __( '<strong>Maintenance mode</strong> is currently <strong>active</strong>!', 'all-in-one-wp-solution' ) . ' <a href="../admin.php?page=all-in-one-wp-solution&tab=maintenance">' . __( 'Deactivate it, when work is done', 'all-in-one-wp-solution' ) . '</a>.</p></div>';
}

if ( is_multisite() && is_plugin_active_for_network( 'all-in-one-wp-solution/includes/class-maintenance-mode.php' ) )
add_action( 'network_admin_notices', 'aiows_network_admin_notices' ); 
add_action( 'admin_notices', 'aiows_admin_notices' ); 
add_filter( 'login_message',
	function() {
		return '<div id="login_error">' . __( '<strong>Maintenance mode</strong> is currently <strong>active</strong>!', 'all-in-one-wp-solution' ) . '</div>';
	} );

/**
 * Maintenance message when active
*/ 

function aiows_maintenance_mode(){
    nocache_headers();
    if( !current_user_can('edit_themes') && !is_user_logged_in() ) {
        wp_die('<h1 style="color:red">' . get_option('aiows_plugin_maintenance_settings')['aiows_plugin_maintenance_header'] .'</h1>' . get_option('aiows_plugin_maintenance_settings')['aiows_plugin_maintenance_body'], __( get_option('aiows_plugin_maintenance_settings')['aiows_plugin_maintenance_custom_title'] . ' - ' . get_bloginfo('name'), 'all-in-one-wp-solution' ), array('response' => '503'));
    }
}
add_action('get_header', 'aiows_maintenance_mode');

?>
